@@ -286,6 +286,7 @@ run(int *fd, ...)
 	     i < countof(cmdline) &&
 		     (cmdline[i] = va_arg(vap, char*)) != NULL; i++);
 	va_end(vap);
+	assert(*cmdline);
 
 	if (pipe(intfd) < 0) {
 		error("pipe setup to/from %s failed", cmdline[0U]);
@@ -805,7 +806,6 @@ bzr_version(struct yuck_version_s v[static 1U])
 			break;
 		}
 		/* read over all the whitespace to find the tag's revno */
-		while (*++bp == ' ');
 		with (unsigned int rno = strtoul(bp, NULL, 10)) {
 			v->dist = v->rvsn - rno;
 		}
